@@ -1,9 +1,10 @@
-"""jc - JSON Convert `dig` command output parser
+r"""jc - JSON Convert `dig` command output parser
 
 Options supported:
 - `+noall +answer` options are supported in cases where only the answer
   information is desired.
 - `+axfr` option is supported on its own
+- `+nsid` option is supported
 
 The `when_epoch` calculated timestamp field is naive. (i.e. based on the
 local time of the system the parser is run on)
@@ -101,7 +102,7 @@ Schema:
     ]
 
     [0] naive timestamp if "when" field is parsable, else null
-    [1] timezone aware timestamp availabe for UTC, else null
+    [1] timezone aware timestamp available for UTC, else null
 
 Examples:
 
@@ -322,12 +323,13 @@ import jc.utils
 
 class info():
     """Provides parser metadata (version, author, etc.)"""
-    version = '2.4'
+    version = '2.5'
     description = '`dig` command parser'
     author = 'Kelly Brazil'
     author_email = 'kellyjonbrazil@gmail.com'
     compatible = ['linux', 'aix', 'freebsd', 'darwin', 'win32', 'cygwin']
     magic_commands = ['dig']
+    tags = ['command']
 
 
 __version__ = info.version
@@ -426,6 +428,7 @@ def _parse_flags_line(flagsline):
 def _parse_opt_pseudosection(optline):
     # ;; OPT PSEUDOSECTION:
     # ; EDNS: version: 0, flags:; udp: 4096
+    # ; NSID: 67 70 64 6e 73 2d 73 66 6f ("gpdns-sfo")
     # ; COOKIE: 1cbc06703eaef210
     if optline.startswith('; EDNS:'):
         optline_list = optline.replace(',', ' ').split(';')
@@ -442,11 +445,18 @@ def _parse_opt_pseudosection(optline):
             }
         }
 
-    elif optline.startswith('; COOKIE:'):
+    if optline.startswith('; COOKIE:'):
         return {
             'cookie': optline.split()[2]
         }
 
+    if optline.startswith('; NSID:'):
+        return {
+            'nsid': optline.split('("')[-1].rstrip('")')
+        }
+
+    return {}
+
 
 def _parse_question(question):
     # ;www.cnn.com.           IN  A
